@@ -143,31 +143,6 @@ static void noteBaseConsonant(Output *output)
     }
 }
 
-static void shiftCharsLeft3(Output *output)
-{
-    if (output->fOutChars != NULL) {
-	gunichar temp_char;
-	guint32 temp_index;
-	gulong temp_tag;
-
-	temp_char = output->fOutChars[output->fOutIndex - 3];
-	temp_index = output->fCharIndices[output->fOutIndex - 3];
-	temp_tag = output->fCharTags[output->fOutIndex - 3];
-
-	output->fOutChars[output->fOutIndex - 3] = output->fOutChars[output->fOutIndex - 2];
-	output->fCharIndices[output->fOutIndex - 3] = output->fCharIndices[output->fOutIndex - 2];
-	output->fCharTags[output->fOutIndex - 3] = output->fCharTags[output->fOutIndex - 2];	
-
-	output->fOutChars[output->fOutIndex - 2] = output->fOutChars[output->fOutIndex - 1];
-	output->fCharIndices[output->fOutIndex - 2] = output->fCharIndices[output->fOutIndex - 1];
-	output->fCharTags[output->fOutIndex - 2] = output->fCharTags[output->fOutIndex - 1];
-
-	output->fOutChars[output->fOutIndex - 1] = temp_char;
-	output->fCharIndices[output->fOutIndex - 1] = temp_index;
-	output->fCharTags[output->fOutIndex - 1] = temp_tag;
-    }
-}
-
 static void swapChars(Output *output, int a, int b)
 {
     if (output->fOutChars != NULL) {
@@ -410,6 +385,9 @@ glong indic_ot_reorder(const gunichar *chars, const glong *utf8_offsets, glong c
 		    if (IS_VATTU(charClass) && supressVattu) {
 			tag = nukt_p;
 		    }
+		    else if ((i + 2 < baseConsonant) && (chars[i + 2] == C_SIGN_ZWNJ)) {
+			tag = nukt_p;
+		    }
 
 		    supressVattu = IS_VATTU(charClass);
 		} else if (IS_VIRAMA(charClass) && chars[i + 1] == C_SIGN_ZWNJ)
@@ -442,19 +420,43 @@ glong indic_ot_reorder(const gunichar *chars, const glong *utf8_offsets, glong c
 		writeChar(&output, chars[i], /*i*/ prev, nukt_p);
 	    }
 
-            /* for the special conjuction of Cons+0x0d4d+0x0d31 of Malayalam */
+            /* for the special conjuction of Cons+0x0d4d+0x0d31 or Cons+0x0d4d+0x0d30 of Malayalam */
 	    if ((baseConsonant - 2 >= 0) &&
 		(chars[baseConsonant - 1] == 0x0d4d) &&
-		(chars[baseConsonant] == 0x0d31) &&
+		((chars[baseConsonant] == 0x0d31) || 
+		 (chars[baseConsonant] == 0x0d30)) &&
 		((chars[baseConsonant - 2] >= 0x0d15) && 
 		 (chars[baseConsonant - 2] <= 0x0d39)))  {
-		swapChars (&output, -1, -3);
-	    }
+      		swapChars (&output, -1, -3);
+        
+                if (mpreFixups) {
+		    if (mpreFixups->fFixupCount > 0) {
+                        mpreFixups->fFixupCount--;
+		    }
+                }        
+	    }            
 
 	    if ((class_table->scriptFlags & SF_MATRAS_AFTER_BASE) != 0) {
-		writeMbelow(&output);
-		writeMabove(&output);
-		writeMpost(&output);
+		gboolean is_for_0C48 = FALSE;
+	        if (output.fOutChars != NULL) {  /*for 0x0C48 of Telugu*/
+		    int t;
+		    for (t = prev; t < syllable; t++) {
+		        if (chars[t] == 0x0C48) {
+			    writeMabove(&output);
+			    writeMbelow(&output);
+			    writeMpost(&output);
+
+                            is_for_0C48 = TRUE;
+                            break;			    
+			}
+		    }
+		}
+		
+		if (!is_for_0C48) {
+		    writeMbelow(&output);
+		    writeMabove(&output);
+		    writeMpost(&output);
+		}
 	    }
 
 	    /* write below-base consonants */
@@ -496,14 +498,6 @@ glong indic_ot_reorder(const gunichar *chars, const glong *utf8_offsets, glong c
 
 		    /* write halant that was after base consonant */
 		    writeChar(&output, chars[bcSpan], /*bcSpan*/ prev, blwf_p);
-
-		    /* for Ra of Malayalam */
-		    if ((bcSpan - 1 >= 0) && (bcSpan + 1 < char_count) &&
-			(chars[bcSpan] == 0x0d4d) && (chars[bcSpan + 1] == 0x0d30) &&
-			((chars[bcSpan - 1] >= 0x0d15) && (chars[bcSpan - 1] <= 0x0d39))) {
-
-			shiftCharsLeft3 (&output);
-		    }
 		}
 
 		/* write the training halant, if there is one */
