@@ -1081,18 +1081,28 @@ itemize_state_process_run (ItemizeState *state)
       PangoFont *font;
 
       /* We don't want space characters to affect font selection; in general,
-       * it's always wrong to select a font just to render a space.
-       * To make this really work well, we'd need to emulate missing
-       * space characters, which we don't yet do, so we sometimes
-       * will get hex boxes.
+       * it's always wrong to select a font just to render a space.  But until
+       * we have a better solution, choosing a font for spaces seems to work
+       * better.
        *
        * The exception of U+3000 (IDEOGRAPHIC SPACE) here is because we
        * want to choose an ideographic space that matches ideographic text
        * in cell width. Even if we were emulating missing spaces, an
        * emulated ideographic space for the primary font wouldn't be the
        * right size.
+       *
+       * The exception of PrivateUse and Unassigned characters is necessary
+       * to be able to render any of them. (for private or being encoded
+       * scripts, etc.)
        */
-      if (!g_unichar_isgraph (wc) && wc != 0x3000)
+      /*
+      if (G_UNLIKELY (!g_unichar_isgraph (wc) && wc != 0x3000 &&
+		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
+		      g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
+	*/
+      if (G_UNLIKELY (!g_unichar_isprint (wc) &&
+		      g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
+		      g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
 	{
 	  shape_engine = NULL;
 	  font = NULL;
