@@ -27,8 +27,6 @@
 
 G_BEGIN_DECLS
 
-#define PANGO_CAIRO_UNKNOWN_FLAG 0x10000000
-
 #define PANGO_CAIRO_FONT_MAP_GET_IFACE(obj)  (G_TYPE_INSTANCE_GET_INTERFACE ((obj), PANGO_TYPE_CAIRO_FONT_MAP, PangoCairoFontMapIface))
 
 typedef struct _PangoCairoFontMapIface PangoCairoFontMapIface;
@@ -58,8 +56,8 @@ struct _PangoCairoFontIface
 {
   GTypeInterface g_iface;
 
-  void (*install) (PangoCairoFont *font,
-		   cairo_t        *cr);
+  gboolean (*install) (PangoCairoFont *font,
+		       cairo_t        *cr);
 
   cairo_font_face_t *(*get_font_face) (PangoCairoFont *font);
 
@@ -68,8 +66,8 @@ struct _PangoCairoFontIface
 
 GType pango_cairo_font_get_type (void);
 
-void _pango_cairo_font_install (PangoCairoFont *font,
-				cairo_t        *cr);
+gboolean _pango_cairo_font_install (PangoCairoFont *font,
+				    cairo_t        *cr);
 cairo_font_face_t *_pango_cairo_font_get_font_face (PangoCairoFont *font);
 cairo_scaled_font_t *_pango_cairo_font_get_scaled_font (PangoCairoFont *font);
 
@@ -89,14 +87,17 @@ typedef struct _PangoCairoHexBoxInfo PangoCairoHexBoxInfo;
 struct _PangoCairoHexBoxInfo
 {
 	PangoFont *font;
+	int rows;
 	double digit_width;
 	double digit_height;
-	double pad;
+	double pad_x;
+	double pad_y;
+	double line_width;
 	double box_descent;
 	double box_height;
 };
 
-PangoCairoHexBoxInfo *_pango_cairo_get_hex_box_info (PangoCairoFont *font);
+PangoCairoHexBoxInfo *_pango_cairo_font_get_hex_box_info (PangoCairoFont *font);
 
 void _pango_cairo_get_glyph_extents_missing (PangoCairoFont *cfont,
 					     PangoGlyph      glyph,
@@ -107,6 +108,7 @@ typedef struct _PangoCairoWarningHistory PangoCairoWarningHistory;
 
 struct _PangoCairoWarningHistory {
   guint font_install		: 1;
+  guint font_get_scaled_font	: 1;
 }; 
 
 extern PangoCairoWarningHistory _pango_cairo_warning_history;
